@@ -1,6 +1,6 @@
 package Template::Perlish;
 
-$VERSION = '1.30_01';
+$VERSION = '1.30_02';
 
 use 5.008_000;
 use warnings;
@@ -177,24 +177,24 @@ sub _compile_sub {
 
       no warnings 'redefine';
       local *V = sub {
-         my \$path = _smart_split(shift);
+         my \$path = _smart_split(shift) or return '';
          return _V(\\\%variables, \@\$path);
       };
       local *A = sub {
-         my \$path = _smart_split(shift);
-         return \@{_V(\\\%variables, \@\$path)};
+         my \$v = V(shift) or return;
+         return \@\$v;
       };
       local *H = sub {
-         my \$path = _smart_split(shift);
-         return \%{_V(\\\%variables, \@\$path)};
+         my \$v = V(shift) or return;
+         return \%\$v;
       };
       local *HK = sub {
-         my \$path = _smart_split(shift);
-         return keys \%{_V(\\\%variables, \@\$path)};
+         my \$v = V(shift) or return;
+         return keys \%\$v;
       };
       local *HV = sub {
-         my \$path = _smart_split(shift);
-         return values \%{_V(\\\%variables, \@\$path)};
+         my \$v = V(shift) or return;
+         return values \%\$v;
       };
       use warnings 'redefine';
 
@@ -355,7 +355,7 @@ Template::Perlish - Yet Another Templating system for Perl
 
 =head1 VERSION
 
-This document describes Template::Perlish version 1.21. Most likely, this
+This document describes Template::Perlish version 1.40. Most likely, this
 version number here is outdate, and you should peek the source.
 
 
